translate.storage.catkeys.CatkeysHeader

Package translate :: Package storage :: Module catkeys :: Class CatkeysHeader |
[hide private]
[frames] | no frames]

# Class CatkeysHeader

source code

A catkeys translation memory header

Instance Methods | [hide private]
__init__(self, header=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_create_default_header(self) Create a default catkeys header | source code
settargetlanguage(self, newlang) Set a human readable target language | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| targetlanguage = `property(None, settargetlanguage)`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, header=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)